##  Changing the Link to a Different Item
You can link a fact sheet to a different catalog item if there is a more appropriate one or if it was inadvertently linked to the current item. Follow these steps:
  1. On the reference catalog page, navigate to the Linked tab.
  2. Select a fact sheet, click on the search field to see alternate recommendations or to search for a specific item to change to.
  3. Choose the appropriate recommendation you want to change to, and click Change Link.


![Changing the Link to a Different Item](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27546f917a4410149f119bb88c1cfcdf_LowRes.png)
Changing the Link to a Different Item
